==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.chronos.compat.impl/src/com/openexchange/chronos/compat/impl/osgi/ChronosCompatActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos.compat.impl.osgi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.chronos.compat.impl.attachments.CalendarAttachmentHandler;
import com.openexchange.chronos.service.CalendarService;
import com.openexchange.folderstorage.FolderService;
import com.openexchange.groupware.Types;
import com.openexchange.groupware.attach.Attachments;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link ChronosCompatActivator}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class ChronosCompatActivator extends HousekeepingActivator {

    private static final Logger LOG = LoggerFactory.getLogger(ChronosCompatActivator.class);

    private volatile CalendarAttachmentHandler attachmentHandler;

    /**
     * Initializes a new {@link ChronosCompatActivator}.
     */
    public ChronosCompatActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { CalendarService.class, FolderService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        try {
            LOG.info("starting bundle {}", context.getBundle());
            /*
             * inject legacy calendar attachment authorization & listener
             */
            CalendarAttachmentHandler attachmentHandler = new CalendarAttachmentHandler(this);
            Attachments.getAuthorizationChooserForModule(Types.APPOINTMENT).registerForEverything(attachmentHandler, 18);
            Attachments.getListenerChooserForModule(Types.APPOINTMENT).registerForEverything(attachmentHandler, 18);
            this.attachmentHandler = attachmentHandler;
            openTrackers();
        } catch (Exception e) {
            LOG.error("error starting {}", context.getBundle(), e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        LOG.info("stopping bundle {}", context.getBundle());
        CalendarAttachmentHandler attachmentHandler = this.attachmentHandler;
        if (null != attachmentHandler) {
            Attachments.getListenerChooserForModule(Types.APPOINTMENT).removeForEverything(attachmentHandler);
            Attachments.getAuthorizationChooserForModule(Types.APPOINTMENT).removeForEverything(attachmentHandler);
            this.attachmentHandler = null;
        }
        super.stopBundle();
    }

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.chronos.compat.impl/src/com/openexchange/chronos/compat/impl/osgi/ChronosCompatActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos.compat.impl.osgi;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.chronos.compat.impl.attachments.CalendarAttachmentHandler;
import com.openexchange.chronos.service.CalendarService;
import com.openexchange.folderstorage.FolderService;
import com.openexchange.groupware.Types;
import com.openexchange.groupware.attach.Attachments;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link ChronosCompatActivator}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class ChronosCompatActivator extends HousekeepingActivator {

    private CalendarAttachmentHandler attachmentHandler;

    /**
     * Initializes a new {@link ChronosCompatActivator}.
     */
    public ChronosCompatActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { CalendarService.class, FolderService.class };
    }

    @Override
    protected synchronized void startBundle() throws Exception {
        Logger logger = LoggerFactory.getLogger(ChronosCompatActivator.class);
        try {
            logger.info("starting bundle {}", context.getBundle());
            /*
             * inject legacy calendar attachment authorization & listener
             */
            CalendarAttachmentHandler attachmentHandler = new CalendarAttachmentHandler(this);
            Attachments.getAuthorizationChooserForModule(Types.APPOINTMENT).registerForEverything(attachmentHandler, 18);
            Attachments.getListenerChooserForModule(Types.APPOINTMENT).registerForEverything(attachmentHandler, 18);
            this.attachmentHandler = attachmentHandler;
            openTrackers();
        } catch (Exception e) {
            logger.error("error starting {}", context.getBundle(), e);
            throw e;
        }
    }

    @Override
    protected synchronized void stopBundle() throws Exception {
        LoggerFactory.getLogger(ChronosCompatActivator.class).info("stopping bundle {}", context.getBundle());
        CalendarAttachmentHandler attachmentHandler = this.attachmentHandler;
        if (null != attachmentHandler) {
            Attachments.getListenerChooserForModule(Types.APPOINTMENT).removeForEverything(attachmentHandler);
            Attachments.getAuthorizationChooserForModule(Types.APPOINTMENT).removeForEverything(attachmentHandler);
            this.attachmentHandler = null;
        }
        super.stopBundle();
    }

}
